
/**********************************/
/***** Make Market Shocks *******/
/*********************************/


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"

set more off
clear

*Read in 6-digit baci data
use "${path}/Aggregate Shock/Data/countrypanel_hs6_forbank"

*Note: Exports from overseas companies = input supply
rename exports_real exr

*Note: Imports from overseas companies = export demand
rename imports_real imr

keep hs6 exr imr  iso2 j imports_frompt_real year countrycode

keep if inlist(year,2003,2004,2006,2007,2009,2010)

reshape wide exr imr imports_frompt_real, i(iso2 j hs6 ) j(year)

*Periods to calculate shocks over
local year1s = "0607 0304 07 07 03"
local year2s = "0910 0607 09 10 06"
local names = "0610 0307 0709 0710 0306"
local n: word count `year1s'

*Create averages for paired years
gen exr200607 = (exr2007 + exr2006)/2
gen imr200607 = (imr2007 + imr2006)/2

gen exr200910 = (exr2009 + exr2010)/2
gen imr200910 = (imr2009 + imr2010)/2

gen exr200304 = (exr2003 + exr2004)/2
gen imr200304 = (imr2003 + imr2004)/2

gen imrpt200607 = (imports_frompt_real2007 +imports_frompt_real2006)/2
gen imrpt200910 = (imports_frompt_real2009 +imports_frompt_real2010)/2
gen imrpt200304 = (imports_frompt_real2003 +imports_frompt_real2004)/2

rename imports_frompt_real2007 imrpt2007
rename imports_frompt_real2009 imrpt2009
rename imports_frompt_real2010 imrpt2010
rename imports_frompt_real2006 imrpt2006
rename imports_frompt_real2003 imrpt2003

*Create Changes
forvalues i = 1/`n' {
	local year1: word `i' of `year1s'
	local year2: word `i' of `year2s'
	local name: word `i' of `names'
	
	*Use Arc Elasticities for HS6
	gen m_inp6_`name' = (exr20`year2' - exr20`year1') /  (exr20`year2' + exr20`year1')	
	gen m_dem6_`name' = (imr20`year2' - imr20`year1') /  (imr20`year2' + imr20`year1')	

	replace m_inp6_`name' = 0 if m_inp6_`name' ==.
	replace m_dem6_`name' = 0 if m_dem6_`name' ==.	
}



*Make total chg
preserve
collapse (sum) imr* exr*, by( hs6)

forvalues i = 1/`n' {
	local year1: word `i' of `year1s'
	local year2: word `i' of `year2s'
	local name: word `i' of `names'
	
	*Use Arc Elasticities for HS6
	gen m_inp_tot_`name' = (exr20`year2' - exr20`year1') /  (exr20`year2' + exr20`year1')	
	gen m_dem_tot_`name' = (imr20`year2' - imr20`year1') /  (imr20`year2' + imr20`year1')	

	replace m_inp_tot_`name' = 0 if m_inp_tot_`name' ==.
	replace m_dem_tot_`name' = 0 if m_dem_tot_`name' ==.	
}

drop imr* exr*
tempfile pctch
save `pctch'
restore
merge m:1 hs6 using `pctch', keep(1 3) nogen

*Make mean/wtd mean changes

forvalues i = 1/`n' {
	local year1: word `i' of `year1s'
	local year2: word `i' of `year2s'
	local name: word `i' of `names'
	
	
	*Common components
	
	gen mp1_inp6_`name' = 1 + m_inp6_`name' 
	gen mp1_dem6_`name' = 1 + m_dem6_`name' 
	
	*baseline: raw mean change across markets
	egen m_inp_mn_`name' = mean( m_inp6_`name' ), by(hs6)
	egen m_dem_mn_`name' = mean( m_dem6_`name' ), by(hs6)
	
	*alternative for appendix: global imports weighted mean change across markets
	egen m_inp_wmn_`name' = wtmean( m_inp6_`name' ), weight(exr20`year1') by(hs6)
	egen m_dem_wmn_`name' = wtmean( m_dem6_`name' ), weight(imr20`year1') by(hs6)
	
	*alternative for appendix: portuguese imports weighted mean change across markets
	egen m_dem_pwmn_`name' = wtmean( m_dem6_`name' ), weight(imrpt20`year1') by(hs6)
	
	*alternative for appendix: harmonic mean change across markets
	egen m_inp_hmn_`name' = hmean( mp1_inp6_`name' ),  by(hs6)
	egen m_dem_hmn_`name' = hmean( mp1_dem6_`name' ),  by(hs6)
	
	replace m_inp_hmn_`name' = m_inp_hmn_`name' -1
	replace m_dem_hmn_`name' = m_dem_hmn_`name' -1
	
	*Idiosyncratic components (differencing out common)
	
	gen m_inp_nomn_`name' = m_inp6_`name' - m_inp_mn_`name'
	gen m_dem_nomn_`name' = m_dem6_`name' - m_dem_mn_`name'
	
	gen m_inp_nohmn_`name' = m_inp6_`name' - m_inp_hmn_`name'
	gen m_dem_nohmn_`name' = m_dem6_`name' - m_dem_hmn_`name'
	
	
	gen m_inp_nowmn_`name' = m_inp6_`name' - m_inp_wmn_`name'
	gen m_dem_nowmn_`name' = m_dem6_`name' - m_dem_wmn_`name'
	
	gen m_inp_notot_`name' = m_inp6_`name' - m_inp_tot_`name'
	gen m_dem_notot_`name' = m_dem6_`name' - m_dem_tot_`name'
	
	gen m_dem_nopwmn_`name' = m_dem6_`name' - m_dem_pwmn_`name'


}



drop exr* imr* 


*Country code correspondence, use files as crosswalks
rename countrycode iso3
merge m:1 iso3 using "${path}/Aggregate Shock/Data/country_code_baci92.dta", keep(3) nogen keepus(iso2)

rename iso2 pais_cod
merge m:1 pais_cod using "${path}/Aggregate Shock/Data/recessionshocks.dta", ///
	 keepusing(id_pais) keep(3) nogen
	 
drop if id_pais==238 /*Sudan is messed up in coding, appears as two countries?*/ 

*save file
save "${path}/Aggregate Shock/replication/data_out/core_recessionshocks_hs6.dta", replace

