
/**********************************/
/***** Make Firm-Level Shocks *******/
/*********************************/
/**Code combines market shocks and firm-level exposure to create firm-level shock variable**/

cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"


*Read in trade data
use "${path}/Aggregate Shock/Data/exports_ijpt.dta", clear

merge m:1 year using "${path}/Aggregate Shock/Data/deflator.dta", nogen keep(1 3)

rename HS6 hs6
rename value exports
replace exports = exports*deflator
rename country id_pais

*Main product indicators for 2005-2007
gen hs4 = floor(hs6/100)
gen hs2 = floor(hs6/100) /*NOTE THIS IS WRONG, EXPLAINS WHY 4 and 2 are the same*/

foreach p in hs6 hs4 hs2{ 
	preserve
	keep if inrange(year, 2005, 2007)
	collapse (sum) exports, by(nipc `p')
	bys nipc ( exports): gen order=_n
	bys nipc ( exports): gen ct=_N
	egen main`p' = total(`p' * (order==ct)), by(nipc)
	keep nipcbdp main`p'
	duplicates drop
	save "${path}/Aggregate Shock/replication/data_out/mainprod`p'", replace
	restore
}

*Make outcomes: Number of products
preserve
collapse (sum) exports, by(nipc year hs6)
collapse (count) nprod=hs6, by(nipc year)
save "${path}/Aggregate Shock/replication/data_out/nprodhs6", replace
restore

keep if inrange(year, 2005, 2007)



/*Exposure Weights*/
collapse (sum) exports, by(nipc hs6 id_pais)

/*make baseline weights*/
egen total_exports = total(exports), by(nipc)
gen weight = exports / total_exports


/*Merge on market shocks constructed in perious code*/
merge m:1 id_pais hs6 using "${path}/Aggregate Shock/replication/data_out/core_recessionshocks_hs6.dta", keep(3) nogen 


/*Make flags for in-sample pre-period outlier market shocks within portuguese firms*/

summ m_dem6_0306 , d
local lo = r(p5)
local hi = r(p95)
gen pre_outlier = 0
replace pre_outlier = 1 if  m_dem6_0306 < `lo' | m_dem6_0306 > `hi' 

binscatter m_dem6_0709 m_dem6_0306 if pre_outlier==0
binscatter m_dem6_0610 m_dem6_0306 if pre_outlier==0




/* Make alternative weights among non-outlier markets*/
egen trim_total_exports = total(exports * (pre_outlier==0)), by(nipc)
gen trimweight = (pre_outlier==0) * exports / trim_total_exports




/*Create main shocks and trimmed shocks for appendix*/
foreach t in  "0306" "0610" "0709"  {
			gen shock`t'hs6 = 2*weight * m_dem6_`t' 
			gen impshock`t'hs6 = 2*weight * m_inp6_`t' 
			gen trimshock`t'hs6 = 2*trimweight * m_dem6_`t'* (pre_outlier==0)
		}
		
/*Create idiosynctatic and common components*/		
foreach t in "0610" "0709"  {
	foreach stub in tot mn wmn pwmn hmn{
			gen comshock`t'_`stub' = 2*weight * m_dem_`stub'_`t' 	
			gen idshock`t'_`stub' = 2*weight * m_dem_no`stub'_`t'
			
			
			gen trimcomshock`t'_`stub' = 2*weight * m_dem_`stub'_`t' * (pre_outlier==0)
			gen trimidshock`t'_`stub' = 2*weight * m_dem_no`stub'_`t' * (pre_outlier==0)
		}
	}
*make shocks
*Weight varies within firm by country and product, m´s only vary by country product



collapse (sum) shock* impshock* comshock* idshock*  trimshock* trimcomshock* trimidshock*, by(nipc)

sort nipc

save "${path}/Aggregate Shock/replication/data_out/shocks_hs6", replace


