
**********************************************
* Figures 2 and 3 : Firm Level Event Studies *
* Andy Garin (agarin@illinois.edu)           *
**********************************************

*
*Runs regressions
*
*Plots event study figures
*
*


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"



clear all

*spec counter
local s = 1

foreach c in 0 1{

global continuers = `c'


set more off

*Read in firm-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear
*set matsize 11000

*merge 1:1 nipcbdp year using "${path}/Aggregate Shock/Data/collapse_contemp.dta", keep(1 3) nogen
	
local contin = $continuers

*Rescale exports by total preperiod sales
gen exp_sales_sc = (exports/1000)/turnover_pre


if $continuers == 1 {
	keep if everexit==0
}

keep if mainsamp==1

local mainout  /*Sales*/ exp_sales_sc turnover_sc     ///
				/*labor*/  emp_sc hire_rt_sc same_firm
			
local ny : word count `mainout'


rename l1o4_idshock0610_mn idoth_mn
rename l1o4_comshock0610_mn comoth_mn

local treatsid  idshock0610_mn
			
local treatscomm  comshock0610_mn

gen a = 0	



*Make event study variables

forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
			*year dummy
			gen t`i' = (year == `i')
			*treat interact
			foreach treat in `treatsid' `treatscomm' {

				gen t`i'_`treat' = (year == `i') * `treat'
							
			}
			
			foreach control in  expshrAGO expshrESP{
				gen ccm`i'_`control' = (year == `i') * `control'
			}						
							
			foreach control in expshrAGO expshrESP comshock0610_mn{
				gen c`i'_`control' = (year == `i') * `control'
			}
			
		}
	
}




/************************************************/
/*Baseline event studies: Idiosyncratic Shocks  */
/************************************************/
forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatsid' {



		*Matrix for outcomes
		matrix B_`s' = J(24,1,.)

		*Event-study regression
		reghdfe `yvar' t???? t????_`treat'   c????_*   ///
			if inrange(year, 2005, 2013), ///
			cluster(nipc) absorb(nipc )
			
		local t`s' = "`treat'"
		local o`s' = "`yvar'"
			
		*Store coefficients and SEs	
		forvalues i = 1/9 {
			local year = `i' + 2004
			local j = `i' + 9
			if (`i' == 3) {
				matrix B_`s'[`i', 1] = 0
				matrix B_`s'[`j', 1] = 0
			}
			else {
				matrix B_`s'[`i', 1] = _b[t`year'_`treat']
				matrix B_`s'[`j', 1] = _se[t`year'_`treat']	
			}
		}
		
	
		test (t2005_`treat' = 0) (t2006_`treat' = 0)
		local prep = r(p)
		test ( t2009_`treat' = 0 ) ( t2010_`treat' = 0 )
		local postp = r(p)
		
		local nobs = e(N)
		local nclust = e(N_clust)
		
		
		matrix B_`s'[19, 1] = `nobs'
		matrix B_`s'[20, 1] = `nclust'

		matrix B_`s'[21, 1] = `prep'
		matrix B_`s'[22, 1] = `postp'
		matrix B_`s'[23, 1] = `c'
		matrix B_`s'[24, 1] = `s'
	
		local s = `s' + 1				
	
	}
	
}	


/***************************************/
/*Baseline event studies: Common Shocks*/
/**************************************/


forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatscomm' {


		*Matrix for outcomes
		matrix B_`s' = J(24,1,.)
		
		*Cluster at industry level
		reghdfe `yvar' t???? t????_`treat'   ccm????_*   ///
			if inrange(year, 2005, 2013), ///
			cluster(nace4) absorb(nipc )
		
					
		local t`s' = "`treat'"
		local o`s' = "`yvar'"
		
		*Store coefficients and SEs	
		forvalues i = 1/9 {
			local year = `i' + 2004
			local j = `i' + 9
			if (`i' == 3) {
				matrix B_`s'[`i', 1] = 0
				matrix B_`s'[`j', 1] = 0
			}
			else {
				matrix B_`s'[`i', 1] = _b[t`year'_`treat']
				matrix B_`s'[`j', 1] = _se[t`year'_`treat']	
			}
		}
		

		test (t2005_`treat' = 0) (t2006_`treat' = 0)
		local prep = r(p)
		test ( t2009_`treat' = 0 ) ( t2010_`treat' = 0 )
		local postp = r(p)
		
		local nobs = e(N)
		local nclust = e(N_clust)
		
		matrix B_`s'[19, 1] = `nobs'
		matrix B_`s'[20, 1] = `nclust'

		matrix B_`s'[21, 1] = `prep'
		matrix B_`s'[22, 1] = `postp'
		matrix B_`s'[23, 1] = `c'
		matrix B_`s'[24, 1] = `s'

		local s = `s' + 1	
		
	
	}

}	


}


/**Compile output**/

mat estmat = B_1

local max = `s'-1

forvalues i = 2/`max'{
	mat estmat = [estmat,B_`i']
}

mat OUT= estmat'

drop _all

svmat  OUT



/**Format output**/

forvalues i = 1/9 {
	local year = `i' + 2004
	local j = `i' + 9
	rename OUT`i'  b`year'
	rename OUT`j'  se`year'
	
}
rename OUT19 n_obs
rename OUT20 Nclust
rename OUT21 p_67
rename OUT22 p_910
rename OUT23 continuers
rename OUT24 spec

gen outcome =  "" 
gen tvar =  "" 


forvalues i = 1/`max'{
	replace outcome =  "`o`i''" if spec == `i' 
	replace tvar = "`t`i''"    if spec == `i' 	
}


gen common = tvar=="comshock0610_mn"


save "${path}/Aggregate Shock/replication/output/fig_2_3.dta", replace
export excel "${path}/Aggregate Shock/replication/output/fig_2_3.xls",  first(var) replace 

clear




***************************************
/************PLOT FIGURES**************/
***************************************



******************************************************
* Figure 2
******************************************************

*Do for each panel structure 
forval p=0/1{

use "${path}/Aggregate Shock/replication/output/fig_2_3.dta", clear

keep if continuers == `p' 

*Do for idiosyncratic and common
forval c=0/1 {


if `c'==1 {
loc title ""
loc ytitle "Effect of Shock Component"
}

if `c'==0 {
loc title ""
loc ytitle "Effect of Shock Component"
}


foreach s  in exp_sales_sc turnover_sc {
		mkmat b2005 b2006 b2007 b2008 b2009 b2010 b2011 b2012 b2013 if outcome=="`s'" & common==`c', matrix(b`s'`c')
		mkmat se2005 se2006 se2007 se2008 se2009 se2010 se2011 se2012 se2013 if outcome=="`s'" & common==`c', matrix(se`s'`c')
		numlist "2005/2013"		
		matrix colnames b`s'`c'  = `r(numlist)'
		matrix colnames se`s'`c' = `r(numlist)'
}/*Outcome*/

coefplot (matrix(bexp_sales_sc`c'[1,]), se(seexp_sales_sc`c'[1,])  offset(-.10)  m(s) msize(medium) mc(green%70) ciopts(recast(rcap) lc(green%70) )) /*
		*/(matrix(bturnover_sc`c'[1,]), se(seturnover_sc`c'[1,]) offset(0) m(o) msize(medium) mc(blue%70) ciopts(recast(rcap) lc(blue%70) )) /*
		*/,vertical  ciopts(recast(rcap) lp(-)) yline(0, lc(black)) xline(3.4, lc(gray) lp(-)) ylabel( , grid) ///
			ytitle("`ytitle'" ) yline(0, lc(black))   graphregion(color(white))  ///
			title("`title'") legend(region(color(white)) c(1) pos(6) order(2 "Exports as % of 2007 Sales " 4 "Total Sales as % of 2007 Sales" ) ) name(a`c', replace)
			graph save "${path}/Aggregate Shock/replication/output/F2_shock`c'_cont`p'", replace
			graph export "${path}/Aggregate Shock/replication/output/F2_shock`c'_cont`p'.png", replace
						

} /*Type of shock*/
	

	
} /*Continuers or not*/


******************************************************
* Figure 3
******************************************************

*Do for each panel structure 
forval p=0/1{

use "${path}/Aggregate Shock/replication/output/fig_2_3.dta", clear

keep if continuers == `p' 

*Do for idiosyncratic and common
forval c=0/1 {

loc ytitle "Effect of Shock Component"

if `c'==1 {
loc title "Common component"
loc yscale ""
loc ylabel "ylabel( , grid)" 
}

if `c'==0 {
loc title "Idiosyncratic component"
loc yscale ""
loc ylabel "ylabel( , grid)" 
}

foreach s  in emp_sc hire_rt_sc same_firm {

		mkmat b2005 b2006 b2007 b2008 b2009 b2010 b2011 b2012 b2013 if outcome=="`s'" & common==`c', matrix(b`s'`c')
		mkmat se2005 se2006 se2007 se2008 se2009 se2010 se2011 se2012 se2013 if outcome=="`s'" & common==`c', matrix(se`s'`c')
		numlist "2005/2013"		
		matrix colnames b`s'`c'  = `r(numlist)'
		matrix colnames se`s'`c' = `r(numlist)'
} /*Outcome*/


coefplot (matrix(bemp_sc`c'[1,]), se(seemp_sc`c'[1,])  offset(-.15)  m(o) msize(medium)  mc(gs4%70) ciopts(recast(rcap)  lc(gs4%70) )) /*
	*/(matrix(bhire_rt_sc`c'[1,]), se(sehire_rt_sc`c'[1,]) offset(.0) m(t) msize(medium) mc(green%70)  ciopts(recast(rcap) lc(green%70) ))/*
	*/(matrix(bsame_firm`c'[1,]), se(sesame_firm`c'[1,]) offset(0.2) m(s) msize(medium) mc(red%70)  ciopts(recast(rcap) lc(red%70) )) /*
		*/, vertical  ciopts(recast(rcap) lp(-)) yline(0, lc(black)) xline(3.2, lc(gray) lp(-)) `ylabel' `yscale' ///
			ytitle("`ytitle'" ) yline(0, lc(black))   graphregion(color(white))  ///
			title("") legend(region(color(white)) c(1) pos(6) order(2 "% Change in Employment Since 2007" 4 "Due to Hiring Since 2007" 6 "Due to Retention of 2007 Employees") ) name(a`c', replace)
			graph save "${path}/Aggregate Shock/replication/output/F3_shock`c'_cont`p'", replace
			graph export "${path}/Aggregate Shock/replication/output/F3_shock`c'_cont`p'.png", replace

} /*Type of shock*/
		
	

} /*Continuers or not*/



clear
