
**********************************************
* Figure 4: Individual-Level Event Study	 *
* Andy Garin (agarin@illinois.edu)           *
**********************************************


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"


clear all

*spec counter
local s = 1

foreach c in 0 1{

global continuers = `c'


set more off

*Read in worker-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/worker_panel.dta", clear
	

local contin = $continuers


if $continuers == 1 {
	keep if everexit==0
}


keep if mainsamp==1
gen nace4 = floor(nace5/10)
				
local mainout logrealhwage_stayer  
				
local ny : word count `mainout'



*Shorten name of placebo (rival-firm) shocks
rename l1o4_idshock0610_mn idoth_mn
rename l1o4_comshock0610_mn comoth_mn	

local treatsid  idshock0610_mn idoth_mn
			
local treatscomm  comshock0610_mn comoth_mn


forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
		*year dummy
		gen t`i' = (year == `i')
		*treat interact
		foreach treat in `treatsid' `treatscomm' {
		
			gen t`i'_`treat' = (year == `i') * `treat'
						
		}

		foreach control in  expshrAGO expshrESP{
			gen ccm`i'_`control' = (year == `i') * `control'
		}						
						
		foreach control in expshrAGO expshrESP comshock0610_mn{
			gen c`i'_`control' = (year == `i') * `control'
		}
	}
	
}




/**********************************/
/*Idiosyncratic Shocks            */
/**********************************/
forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatsid' {


		*Matrix for outcomes
		matrix B_`s' = J(24,1,.)

		
		reghdfe `yvar' t???? t????_`treat'   c????_*  ///
			if inrange(year, 2005, 2013), ///
			cluster(nipc) absorb(nss )
			
		local t`s' = "`treat'"
		local o`s' = "`yvar'"
			
		forvalues i = 1/9 {
			local year = `i' + 2004
			local j = `i' + 9
			if (`i' == 3) {
				matrix B_`s'[`i', 1] = 0
				matrix B_`s'[`j', 1] = 0
			}
			else {
				matrix B_`s'[`i', 1] = _b[t`year'_`treat']
				matrix B_`s'[`j', 1] = _se[t`year'_`treat']	
			}
		}
		
	
		test (t2005_`treat' = 0) (t2006_`treat' = 0)
		local prep = r(p)
		test ( t2009_`treat' = 0 ) ( t2010_`treat' = 0 )
		local postp = r(p)
		
		local nobs = e(N)
		local nclust = e(N_clust)
		
		
		matrix B_`s'[19, 1] = `nobs'
		matrix B_`s'[20, 1] = `nclust'

		matrix B_`s'[21, 1] = `prep'
		matrix B_`s'[22, 1] = `postp'
		matrix B_`s'[23, 1] = `c'
		matrix B_`s'[24, 1] = `s'
	
		local s = `s' + 1				

	}
	
}	


/***************************************/
/*Baseline event studies: Common Shocks*/
/**************************************/


forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatscomm' {

		*Matrix for outcomes
		matrix B_`s' = J(24,1,.)
		
		*Cluster at industry level
		reghdfe `yvar' t???? t????_`treat'   ccm????_*  ///
			if inrange(year, 2005, 2013), ///
			cluster(nace4) absorb(nss )
		
					
		local t`s' = "`treat'"
		local o`s' = "`yvar'"
		
		forvalues i = 1/9 {
			local year = `i' + 2004
			local j = `i' + 9
			if (`i' == 3) {
				matrix B_`s'[`i', 1] = 0
				matrix B_`s'[`j', 1] = 0
			}
			else {
				matrix B_`s'[`i', 1] = _b[t`year'_`treat']
				matrix B_`s'[`j', 1] = _se[t`year'_`treat']	
			}
		}
		

		test (t2005_`treat' = 0) (t2006_`treat' = 0)
		local prep = r(p)
		test ( t2009_`treat' = 0 ) ( t2010_`treat' = 0 )
		local postp = r(p)
		
		local nobs = e(N)
		local nclust = e(N_clust)
		
		
		matrix B_`s'[19, 1] = `nobs'
		matrix B_`s'[20, 1] = `nclust'

		matrix B_`s'[21, 1] = `prep'
		matrix B_`s'[22, 1] = `postp'
		matrix B_`s'[23, 1] = `c'
		matrix B_`s'[24, 1] = `s'

		local s = `s' + 1	
		
	}

}	


}


/**Compile output**/

mat estmat = B_1

local max = `s'-1

forvalues i = 2/`max'{
	mat estmat = [estmat,B_`i']
}

mat OUT= estmat'

drop _all

svmat  OUT



*format output

forvalues i = 1/9 {
	local year = `i' + 2004
	local j = `i' + 9
	rename OUT`i'  b`year'
	rename OUT`j'  se`year'
	
}
rename OUT19 Nobs
rename OUT20 Nclust
rename OUT21 pre_p
rename OUT22 post_p
rename OUT23 continuers
rename OUT24 spec

gen outvar =  "" 
gen tvar =  "" 


forvalues i = 1/`max'{
	replace outvar =  "`o`i''" if spec == `i' 
	replace tvar = "`t`i''"    if spec == `i' 	
}

rename Nobs n_obs 
rename tvar shock
rename outvar outcome

save "${path}/Aggregate Shock/replication/output/fig_4.dta", replace
export excel "${path}/Aggregate Shock/replication/output/fig_4.xlsx",  first(var) replace 

clear


***************************************
/************PLOT FIGURES**************/
***************************************

******************************************************
* Figure 4
******************************************************

*Do for each panel structure 
forval p=0/1{

use "${path}/Aggregate Shock/replication/output/fig_4.dta", clear
keep if continuers == `p' 


*Common and its placebo
gen common=1 if shock=="comshock0610_mn"
replace common=3 if shock=="comoth_mn"
*Idyosincratic and its placebo
replace common=0 if shock=="idshock0610_mn"
replace common=2 if shock=="idoth_mn"

forval c=0/3 {

foreach s in logrealhwage_stayer {

		mkmat b2005 b2006 b2007 b2008 b2009 b2010 b2011 b2012 b2013 if outcome=="`s'" & common==`c', matrix(b`s'`c')
		mkmat se2005 se2006 se2007 se2008 se2009 se2010 se2011 se2012 se2013 if outcome=="`s'" & common==`c', matrix(se`s'`c')
		numlist "2005/2013"		
		matrix colnames b`s'`c'  = `r(numlist)'
		matrix colnames se`s'`c' = `r(numlist)'
} /*Outcome*/

}/*Type of shock*/


forval type=0/1 {
loc placebo = `type'+2

if `type'==1 {
loc title "Common component"
}

if `type'==0 {
loc title "Idiosyncratic component"
}
			
coefplot (matrix(blogrealhwage_stayer`type'[1,]), se(selogrealhwage_stayer`type'[1,])  offset(-.15)  m(O)  mc(blue%70) ciopts(recast(rcap)  lc(blue%70))) /*
		
		*/(matrix(blogrealhwage_stayer`placebo'[1,]), se(selogrealhwage_stayer`placebo'[1,])  offset(0)  m(Dh)  mc(gs6%70) ciopts(recast(rcap)  lc(gs6%50))) /*
		
		*/, vertical  ciopts(recast(rcap) lp(-)) yline(0, lc(black)) xline(3.2, lc(gray) lp(-)) ylabel( , grid) ///
			ytitle("Log Real Wage Effect" ) yline(0, lc(black))   graphregion(color(white))  ///
			title("") legend(region(color(white)) c(1) order(2 "Workers at Shocked Firm" 4 "Workers at Other Sample Firms in Same Municipality + 4-Digit Industry") ) name(d`type', replace)
			graph save "${path}/Aggregate Shock/replication/output/F4_shock`type'_cont`p'", replace
			graph export "${path}/Aggregate Shock/replication/output/F4_shock`type'_cont`p'.png", replace

			
}


} /*Continuers or not*/

clear
