
**********************************************
* Table 10: Worker  Heterogeneity     	     *
* Andy Garin (agarin@illinois.edu)           *
***********************************************


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"


*spec counter
local s = 1

*Loop over each subgroup
foreach grp in  nohs hs bcsk bcun wc bc male female perm ftc wagehi wagelo {
foreach c in  0 1{

global continuers = `c'


clear all
set more off
*read in data

*Read in worker-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/worker_panel.dta", clear
	

local contin = $continuers

keep if mainsamp==1

gen hs= (hsdeg == 1 | coldeg==1)

keep if `grp'==1


if $continuers == 1 {
	keep if everexit==0
}


local contin = $continuers


tsset nss year


*Outcomes 		
local outcomes logrealhwage_stayer logrealsalary_stayer 
						
local ny : word count `outcomes'




*Treatments


local treats  shock0610_mn 
	


***Gen diff in diff samples
gen prepost = inlist(year,2006,2007,2009,2010,2011)
gen post = inlist(year,2009,2010,2011)


**gen treat * post

foreach treat in `treats'{
		gen ti_`treat' = (post==1)* id`treat'
}



*Make controls, including annual common
	
forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
		*year dummy
		gen t`i' = (year == `i')

		
		foreach control in expshrAGO expshrESP{
			gen c`i'_`control' = (year == `i') * `control'
		}
		
		*Com is done separately to allow shock division to vary across spec
		foreach treat in `treats'{
			gen tc`i'_`treat' = (year == `i')* com`treat'
		}
				
	}
}



/**********************************/
/* Just Idiosyncratic Shocks Here */
/**********************************/
forvalues y = 1/`ny'{
	foreach treat in  `treats' {

		cap drop t_i_var
		gen t_i_var = ti_`treat'

		local yvar : word `y' of `outcomes' 
		local ytitle : word `y' of `outcomes' 		

		
		local tv = "`treat'"
		local ov = "`yvar'"
		local gv = "`grp'"
		
		matrix IVmat = J(2,7,.)


		
		*Reduced Form
			
		reghdfe `yvar' t???? t_i_var tc????_`treat' c????_*  ///
			if inrange(year, 2005, 2013) & prepost==1  , ///
			cluster(nipc)  absorb(nss )
			
		local nobs = e(N)
			
		*Make RF last entry in each 
		matrix IVmat[2, 1] = `s', `c', _b[t_i_var], _se[t_i_var], `nobs', 0, 0	

		
		ivreghdfe `yvar' t????  c????_* tc????_`treat' (logturnover = t_i_var)      ///
			if inrange(year, 2005, 2013) & prepost==1  , ///
			cluster(nipc)  absorb(nss) ffirst
			
		matrix F = e(first)	
		local f = F[4,1]
		local nobs = e(N)
			

		matrix IVmat[1, 1]  = `s', `c', _b[logturnover], _se[logturnover], `nobs', 1, `f'
	
	
		*Write output from specification to disk 
		
		preserve
		
		drop _all

		svmat  IVmat
		
		rename IVmat1 spec
		rename IVmat2 continuers
		rename IVmat3 beta
		rename IVmat4 se
		rename IVmat5 n
		rename IVmat6 iv
		rename IVmat7 f
		gen outvar =  "`ov'" 
		gen tvar = "`tv'"  
		gen gvar = "`gv'"    	
		
		save "${path}/Aggregate Shock/replication/temp/IVz_`s'.dta", replace
		
		
		drop _all

		
		restore
		
		
		local s = `s' + 1	

					
	}
}

	

}
}


/**Compile output**/

local max = `s'-1

use "${path}/Aggregate Shock/replication/temp/IVz_1.dta", clear

forvalues i = 2/`max' {
	append using "${path}/Aggregate Shock/replication/temp/IVz_`i'.dta"
}

save "${path}/Aggregate Shock/replication/output/Table_10.dta", replace
export excel  "${path}/Aggregate Shock/replication/output/Table_10.xlsx", replace firstrow(variables)

*clear files
forvalues i = 1/`max' {
	erase "${path}/Aggregate Shock/replication/temp/IVz_`i'.dta"
}
 
