
************************************
* Tables 1 and 2, Summary Stats   *
* Andy Garin (agarin@illinois.edu) *
************************************

*
*Note: Full-count firm level variables for table 2 did not transfer to BPLIM, but worker variables did. 
*
*Saves regression parameters as dataset to tabulate offline
*
*


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"




/**************************/
/**EXPORT STATS (Table 1)**/
/**************************/


set more off
cap log close

clear all
set more off

*Read in firm-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear

keep if year==2007
drop if shock0610hs6==0 | shock0610hs6==.

cap log close

gen hihet= inrange(ind5d_ooswmn_quit_perm,.136,1) if ind5d_ooswmn_quit_perm!=.
log using  "${path}/Aggregate Shock/replication/Table1.txt", text replace
rename nprod nprod2

merge 1:1 nipcbdp year using "${path}/Aggregate Shock/Data/nprodhs6", keep(1 3)nogen
gen contsamp = mainsamp==1 & everexit==0
gen mfsamp = mainsamp ==1 & cae3_2d<40

**************************************************
*Tabulations for Table 1 "Analysis Sample"
**************************************************

summ exports expint_pre ndest nprod2 nprod if mainsamp==1, d

**************************************************
*Tabulations for Table 1 "Large Firms"
**************************************************

summ exports expint_pre ndest nprod2 nprod if mainsamp!=1 & employees>5, d /*Not in mainsamp and emp>5 means >100 emps*/

**************************************************
*Comparable Tabulations for Table 1 "Analysis Sample", Just Never-Exiters
**************************************************

summ exports expint_pre ndest nprod2 nprod if mainsamp==1 & hihet==1, d


log close



/**************************/
/**WORKER STATS (Table 2)**/
/**************************/


clear
set more off


**FIRST, FULL-COUNT**

use "${path}/Aggregate Shock/Data/draft1_allsample_workers_clean2007"
keep if year==2007
merge m:1 nipcbdp using "${path}/Aggregate Shock/Data/treatments_for_emp", keepusing(ind5d_ooswmn_quit_perm shock0610hs6 mainsamp  everexit)
gen hihet= inrange(ind5d_ooswmn_quit_perm,.136,1) if ind5d_ooswmn_quit_perm!=.
replace mainsamp=0 if shock0610hs6==0 | shock0610hs6==.

drop if _merge==2
drop _merge

cap log close
gen contsamp = mainsamp==1 & everexit==0
gen mfsamp = mainsamp ==1 & cae3_2d<40

keep if inrange( hnormal, 120, 200)

log using  "${path}/Aggregate Shock/replication/Table2_workerdist.txt", text replace

**************************************************
*Tabulations for "Analysis Sample, Workers" Table 2
**************************************************

summ /*monthly wage*/ rem_base /*hrly wage*/ nomhwage /*log mthly*/ lognomsalary /*log hrly*/ lognomhwage   ///
		/*fixed term share*/ ftc /*tenure*/ tenure /*female share*/ female /*monthly reg hours*/ hnormal if mainsamp==1, d

**************************************************
*Tabulations for "Full-Count Data, Workers" Table 2
**************************************************

summ /*monthly wage*/ rem_base /*hrly wage*/ nomhwage /*log mthly*/ lognomsalary /*log hrly*/ lognomhwage   ///
		/*fixed term share*/ ftc /*tenure*/ tenure /*female share*/ female /*monthly reg hours*/ hnormal, d
		

**************************************************
*Tabulations for "High Separation Subsample" Table A.1
**************************************************		
		
summ /*monthly wage*/ rem_base /*hrly wage*/ nomhwage /*log mthly*/ lognomsalary /*log hrly*/ lognomhwage   ///
		/*fixed term share*/ ftc /*tenure*/ tenure /*female share*/ female /*monthly reg hours*/ hnormal if mainsamp==1 & hihet==1, d

**************************************************
*Tabulations for "Low Separation Subsample" Table A.1
**************************************************	
		
summ /*monthly wage*/ rem_base /*hrly wage*/ nomhwage /*log mthly*/ lognomsalary /*log hrly*/ lognomhwage   ///
		/*fixed term share*/ ftc /*tenure*/ tenure /*female share*/ female /*monthly reg hours*/ hnormal if mainsamp==1 & hihet==0, d
		
**************************************************
*Tabulations for "Never-Exiter Firms" Table A.1
**************************************************			
		
summ /*monthly wage*/ rem_base /*hrly wage*/ nomhwage /*log mthly*/ lognomsalary /*log hrly*/ lognomhwage   ///
		/*fixed term share*/ ftc /*tenure*/ tenure /*female share*/ female /*monthly reg hours*/ hnormal if contsamp==1, d

log close
clear





/**************************/
/**Firms STATS (Table 2)**/
/**************************/


/*  Note: Universe of firms data was not transferred from old hard disk to BPLIM, cannot do full population tabs without*/
/* Only works for in-sample tabulations*/

clear
set more off
*use "E:\Francisca_trade\Aggregate Shock\Data\analysis_samp_allfirms_new" /*file is not on BPLIM*/
*Full universe was constructed by 2_allfirms.do on old computer

*Read in firm-level cleaned data, use original (not replication) copy. Cannot do comparison to firm universe, just sample description. 
use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear

keep if year==2007
merge m:1 nipcbdp using "${path}/Aggregate Shock/Data/treatments_for_emp", keepusing(ind5d_ooswmn_quit_perm shock0610hs6 mainsamp expint_pre expint_new_pre everexit)

replace mainsamp=0 if shock0610hs6==0 | shock0610hs6==.

drop if _merge==2
drop _merge

gen hihet= inrange(ind5d_ooswmn_quit_perm,.136,1) if ind5d_ooswmn_quit_perm!=.
cap log close
log using  "${path}/Aggregate Shock/replication/Table2_firmdist.txt", text replace


gen contsamp = mainsamp==1 & everexit==0
gen mfsamp = mainsamp ==1 & cae3_2d<40

gen mf= cae3_2d<40



cap gen yl = turnover/emp
cap gen val = va_alt1/emp
gen lnyl = log(yl)
gen lnval = log(val)


**************************************************
*Tabulations for "Analysis Sample, Firms" Table 2
**************************************************

summ emp  yl val  if mainsamp==1, d

**************************************************
*Tabulations for "High Separation Subsample" Table A.1
**************************************************		

summ emp  yl val  if mainsamp==1 & hihet==1, d

**************************************************
*Tabulations for "Low Separation Subsample" Table A.1
**************************************************	

summ emp  yl val  if mainsamp==1 & hihet==0, d

**************************************************
*Tabulations for "Never-Exiter Firms" Table A.1
**************************************************

summ emp  yl val  if contsamp==1, d



******************************
**Tabs For Histograms in A.3**
******************************



gen empbin = 1 if inrange(employees,1,2)
replace empbin = 2 if inrange(employees,3,10)
replace empbin = 3 if inrange(employees,11,25)
replace empbin = 4 if inrange(employees,26,50)
replace empbin = 5 if inrange(employees,51,100)
replace empbin = 6 if inrange(employees,101,1000)
replace empbin = 7 if inrange(employees,1001,1000000000)


gen salesbin = 1 if turnover<=1
replace salesbin = 2 if inrange(turnover,1,10)
replace salesbin = 3 if inrange(turnover,10,100)
replace salesbin = 4 if inrange(turnover,100,1000)
replace salesbin = 5 if inrange(turnover,1000,1000000000)

cap drop indbin

gen indbin = 1 if inrange(cae3_2d,1,4)
replace indbin = 2 if inrange(cae3_2d,5,9)
replace indbin = 3 if inrange(cae3_2d,10,39)
replace indbin = 4 if inrange(cae3_2d,40,53)
replace indbin = 5 if inrange(cae3_2d,54,100)

label define empbin1 1 "1-2" 2 "3 - 10" 3 "11 - 25" 4 "26 - 50" 5 "51 - 100" 6 "101 - 1000" 7 "1001 +"
label define salesbin1 1 "<1K" 2 "1 - 10K" 3 "10 - 100K" 4 "100K - 1M" 5 "1M + " 

label define indbin1 1 "Agric" 2 "Min" 3 "Manuf" 4 "Selling/Dist" 5 "Serv"


label values empbin empbin1
label values salesbin salesbin1
label values indbin indbin1

/*Calculate totals and counts in each bin for histograms*/


*tab empbin 
*tab empbin [fweight=employees]
tab empbin if mainsamp==1
tab empbin if mainsamp==1 [fweight=employees]

*tab indbin 
*tab indbin [fweight=indbin]
tab indbin if mainsamp==1
tab indbin if mainsamp==1 [fweight=indbin]



log close




