
**********************************************
* Table 3 Test of Sorting, like Khwaja / Mian*
* Also Figure A.4							 *
* Andy Garin (agarin@illinois.edu)           *
***********************************************

set more off

cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"


**********************************************
* Pepare Bilateral Trade Data for Regs       *
* Files are Archived, Run from kmdata build  *
**********************************************

/*
/*Build pair-level data*/
use "${path}/Aggregate Shock/Data/exports_ijpt.dta", clear
rename HS6 hs6
rename value exports
rename country id_pais

*deflators
merge m:1 year using "${path}/Aggregate Shock/Data/deflator.dta", nogen keep(1 3)

replace exports = exports * deflator

*Make weights based on full relationshup with country over entire period, WITHIN HS6 BUCKETS
*Collapse across years and products to firm-country level
collapse (sum) exports, by(nipc hs6 id_pais year)

gen cpid = id_pais*100000000 + hs6

keep if year == 2006|year == 2007| year == 2009 | year == 2010
gen t=0

replace t=1 if  year == 2006|year == 2007
replace t=2 if year == 2009 | year == 2010
merge m:1 nipc year using "${path}/Aggregate Shock/Data/firms_nace5", keep(3) nogen 
gen tempnace=NACE5
egen nace5d= mode(tempnace), by(nipc)
replace exports = 0 if exports == .
gen logexports =log(exports)
gen log2exports = log(exports+1)
collapse (mean) exports logexports log2exports (firstnm) nace5d, by(nipc hs6 id_pais t)

egen groupid = group(nipc id_pais hs6)
tsset groupid t

tsfill, full

foreach v in hs6 nipc id_pais nace5d{
	replace `v'=0 if `v'==.
	egen temp = max(`v'), by(groupid)
	replace `v' = temp if `v'==0
	drop temp
}

merge m:1 nipcbdp using Data\treatments_for_emp
keep if _merge == 3
drop _merge
keep if mainsamp

*merge on recession shocks
merge m:1 id_pais hs6 using "${path}/Aggregate Shock/Data/core_recessionshocks_hs6.dta", keep(3) nogen 
cap drop hs4 
gen hs4 = floor(hs6/100)
gen hs2 = floor(hs4/100)
merge m:1 hs4 using "{path}/Aggregate Shock/Data/p4only_shock", keep(3) nogen 

tsset groupid t

save "${path}/Aggregate Shock/replication/data_out/kmdata", replace
*/




********************************************
* Main Analysis 					       *
********************************************

*Read in origal copy for firm x destination cleaned data (original, not replication copy)
use "${path}/Aggregate Shock/Data/kmdata.dta", clear

replace log2exports = 0 if log2exports==.

replace exports = 0 if exports==.

*arc elasticities
gen ae_num = exports - L.exports
gen ae_den = exports + L.exports

gen elast = logexports - L.logexports
gen elast_alt = log2exports - L.log2exports 
gen any_exp = exports>0 & exports!=.


gen exports_init =  L.exports
keep if t==2
keep if exports_init!=.	& exports_init!=0	

bys id_pais hs6: gen order=_n

/*Winsorize Shocks*/
foreach var in m_dem6_0306   m_dem6_0610{
	summ `var' if order==1, d 
	local t1 = r(p10)
	local t2 = r(p90)
	replace `var' = `t1' if `var'<`t1' & `var'!=.
	replace `var' = `t2' if `var'>`t2' & `var'!=.
	summ `var' if order==1, d 
	local sd = r(sd)
	gen st`var' = `var'/`sd'
}


/*Plot Serial correlations for fig A4 */

foreach fp in m_dem6_0306 {
	summ `fp' if order==1
	local xpos = r(max)
	summ m_dem6_0610 if order==1
	local ypos = r(max)
	
	reg stm_dem6_0610  st`fp', cluster(hs6)
	local b = _b[st`fp']
	local b= round(`b',.001)
	local se = _se[st`fp']
	local se= round(`se',.001)
	binscatter   m_dem6_0610 `fp' if order==1, ytitle("") xtitle("") text(.02 .4 "Corr `b' (`se')", size(large))  line(none)
	graph export "${path}/Aggregate Shock/replication/output/FA4_nofe.pdf", replace

	
	reghdfe stm_dem6_0610 st`fp', absorb(hs6) cluster(hs6)
	local b = _b[st`fp']
	local b= round(`b',.001)
	local se = _se[st`fp']
	local se= round(`se',.001)
	binscatter   m_dem6_0610 `fp' if order==1, ytitle("") xtitle("") absorb(hs6) text(.02 .4 "Corr `b' (`se')", size(large)) line(none)
	graph export "${path}/Aggregate Shock/replication/output/FA4_fe.pdf", replace
}	

gen arcelast= ae_num / ae_den

/*Winsorize Outcomes*/
foreach var in elast elast_alt arcelast{
	summ `var', d 
	local t1 = r(p10)
	local t2 = r(p90)
	replace `var' = `t1' if `var'<`t1' & `var'!=.
	replace `var' = `t2' if `var'>`t2' & `var'!=.
	summ `var', d 
	local sd = r(sd)
	gen st`var' = `var'/`sd'
}

*Firm level controls
foreach control in expshrAGO expshrESP{
			gen cont_`control' =  `control'
		}
		
gen cpid = id_pais + hs6*1000	
egen nprod = total( exports_init!=0 &  exports_init!=. ), by(nipc)
egen totexp = total( exports_init), by(nipc)		
gen wt_alt = exports_init/totexp

		
keep if nprod>2
gen nace4d = floor(nace5d/10)
drop if wt3==0

/*Main output for Tabe 3*/


foreach w in 1{
	foreach fe in t{
		local r replace
		foreach yvar in elast arcelast any_exp{
		
			matrix out`yvar'`w'`fe' = J(2,2,.)
			
			reghdfe `yvar' m_dem6_0610, ///
				cluster(nipc cpid) absorb(`fe')
				outreg2 m_dem6_0610 using "${path}/Aggregate Shock/replication/output/Table_3_fe`fe'.xml", excel  `r' addtext(spec, "raw")
			local r append
			
			
			
			reghdfe `yvar' m_dem6_0610 cont_* , ///
				cluster(nipc cpid) absorb(`fe') 
				outreg2 m_dem6_0610 using "${path}/Aggregate Shock/replication/output/Table_3_fe`fe'.xml", excel append addtext(spec, "control")
			
			matrix  out`yvar'`w'`fe'[1,1] = _b[m_dem6_0610], _se[m_dem6_0610]
			
			reghdfe `yvar' m_dem6_0610, ///
				cluster(nipc cpid) absorb(nipc `fe') 
				outreg2 m_dem6_0610 using "${path}/Aggregate Shock/replication/output/Table_3_fe`fe'.xml", excel append addtext(spec, "FE")
		
			matrix  out`yvar'`w'`fe'[2,1] = _b[m_dem6_0610], _se[m_dem6_0610]
			
		}
	}
	
}

clear
		
