
************************************
* Table 4: Firm Level Sales Regs   *
* Andy Garin (agarin@illinois.edu) *
************************************

*
*Runs regressions for Table 4.
*
*Saves regression parameters as dataset to tabulate offline
*
*


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"

	
*Do twice, once for full sample and once for balanced panel of continuer firms 

foreach c in 0 1{

global continuers = `c'


clear all
set more off

*Read in firm-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear

set matsize 11000

local contin = $continuers

*Read in firm-level cleaned data, use original (not replication) copy
merge 1:1 nipcbdp year using "${path}/Aggregate Shock/Data/newdests.dta", keep(1 3) nogen
merge 1:1 nipcbdp year using "${path}/Aggregate Shock/Data/newprods.dta", keep(1 3) nogen	
				
				
				
if $continuers == 1 {
	keep if everexit==0
}

*Restrict to core sample

keep if mainsamp==1

				
*4D Industry for clusting common shocks				
gen ind4_07 = floor(ind5_07/10)	

*Rescale exports by pre-period sales, to be in consistent dollars with sales % change 
gen exp_sales_sc = (exports/1000)/turnover_pre


*outcomes 
				
local mainout  logexports lturnover exp_sales_sc turnover_sc  newdest anynewdest newprod anynewprod any_emp
			
local ny : word count `mainout'
		

*main shocks
		
local treatsid  idshock0610_mn  
			
local treatscomm  shock0610hs6  comshock0610_mn

	
/*Define Specs*/

*Select Pre and Post Yeats
gen prepost = inlist(year,2006,2007,2009,2010,2011)

gen post = inlist(year,2009,2010,2011)
	
*control for year-specific effects of expshrAGO expshrESP
*also control for year-specific effects of comshock0610_mn in idiosync. specs

local c_id = "cS????_*"
local c_com = "cCS????_*"


forvalues i = 2005/2013 {
	*omit 2007
	if (`i' != 2007) {
	
		*Control x Year

		
		foreach control in comshock0610_mn expshrAGO expshrESP  {
			gen cS`i'_`control' = (year == `i') * `control'
		}		
		
		foreach control in expshrAGO expshrESP  {
			gen cCS`i'_`control' = (year == `i') * `control'
		}	

		*year dummy
		gen t`i' = (year == `i')
			
			
	}
}	
	
	
*Treat * Post
foreach treat in `treatsid' `treatscomm'  {
			gen t_`treat' = (post==1)* `treat'
}

	
/**********************************/
/* Idiosyncratic Shocks           */
/**********************************/

forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatsid' {

	
		*Matrix for outcomes
		matrix B`treat'_`yvar' = J(6,1,.)

		reghdfe `yvar' post if prepost==1, absorb(nipc)
		local basechg = _b[post]
		
	
		*Diff-in-diff regression
		reghdfe `yvar' t???? t_`treat' `c_id' ///
			if prepost==1 , ///
			cluster(nipc) absorb(nipc)
		
		
		*Store estimates
		local b = _b[t_`treat']
		local se = _se[t_`treat']		
		local nobs = e(N)
		local nclust = e(N_clust)
		local tst = `b'/(`se')

	
		matrix B`treat'_`yvar'[1,1]=`b'
		matrix B`treat'_`yvar'[2,1]=`se'
		matrix B`treat'_`yvar'[3,1]=`tst'
		matrix B`treat'_`yvar'[4,1]=`nobs'
		matrix B`treat'_`yvar'[5,1]=`nclust'
		matrix B`treat'_`yvar'[6,1]=`basechg'

	}
	
}	

*Save output matrices as excel sheet

preserve
drop _all

forvalues y = 1/`ny'{
	local yvar : word `y' of `mainout' 
	
	foreach treat in  `treatsid'{

		svmat B`treat'_`yvar'

	}
}

*********************************************************************************************************************
** Idiosyncratic shock effects in "Bidshock0610_mn" columns. Separate files for full sample and never-exiters
***********************************************************************************************************************

export excel "${path}/Aggregate Shock/replication/output/Table4_idiotreat_continuers`contin'.xlsx",  first(var) replace 
restore

	
/**********************************/
/* Common Shocks               */
/**********************************/
forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatscomm' {

		*Matrix for outcomes
		matrix B`treat'_`yvar' = J(5,1,.)
		
		*Diff-in-diff regression, cluster at industry level
		reghdfe `yvar' t???? t_`treat' `c_com' ///
			if prepost==1 , ///
			cluster(ind4_07) absorb(nipc)
		
	
		local b = _b[t_`treat']
		local se = _se[t_`treat']		
		local nobs = e(N)
		local nclust = e(N_clust)
		local tst = `b'/(`se')	
	

		matrix B`treat'_`yvar'[1,1]=`b'
		matrix B`treat'_`yvar'[2,1]=`se'
		matrix B`treat'_`yvar'[3,1]=`tst'
		matrix B`treat'_`yvar'[4,1]=`nobs'
		matrix B`treat'_`yvar'[5,1]=`nclust'
		
	}	
	
}	

*Save output matrices as excel sheet

preserve
drop _all

forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 
	
	foreach treat in  `treatscomm' {
	
		svmat B`treat'_`yvar'
		
	}
}


*********************************************************************************************************************
** Baseline shock effects in "Bshock0610" columns, common shock effects in "Bcomshock0610_mn" columns
** Separate files for full sample and never-exiters
***********************************************************************************************************************


export excel "${path}/Aggregate Shock/replication/output/Table4_commontreat_continuers`contin'.xlsx",  first(var) replace 
restore


}
