
**********************************************
* Table 5: Firm Level Own/Other Regs         *
* Andy Garin (agarin@illinois.edu)           *
***********************************************

*
*Runs regressions for Table 5.
*
*Saves regression parameters as dataset to tabulate offline
*
*

cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"

	
*Do twice, once for full sample and once for balanced panel of  continuer firms (appendix)

foreach c in 0 1{

global continuers = `c'


clear all
set more off
*Read in firm-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear
set matsize 11000

local contin = $continuers
			
				
if $continuers == 1 {
	keep if everexit==0
}

*Restrict to core sample

keep if mainsamp==1


*4D Industry for clusting common shocks				
gen ind4_07 = floor(ind5_07/10)	


*outcomes 
				
local mainout  lturnover lva_alt1 logemp logpay
			
local ny : word count `mainout'


*Shorten name of placebo (rival-firm) shocks
rename l1o4_idshock0610_mn idoth_mn
rename l1o4_comshock0610_mn comoth_mn
rename l1o4_shock0610hs6 othbase			


*Main treatments
local treatsid  idshock0610_mn idoth_mn 
			
local treatscomm  shock0610hs6 othbase comshock0610_mn comoth_mn


/*Define Specs*/

*Select Pre and Post Yeats
gen prepost = inlist(year,2006,2007,2009,2010,2011)

gen post = inlist(year,2009,2010,2011)
	
*control for year-specific effects of expshrAGO expshrESP
*also control for year-specific effects of comshock0610_mn in idiosync. specs

local c_id = "cS????_*"
local c_com = "cCS????_*"


forvalues i = 2005/2013 {
	*omit 2007
	if (`i' != 2007) {
	
		*Control x Year

		
		foreach control in comshock0610_mn expshrAGO expshrESP  {
			gen cS`i'_`control' = (year == `i') * `control'
		}		
		
		foreach control in expshrAGO expshrESP  {
			gen cCS`i'_`control' = (year == `i') * `control'
		}	

		*year dummy
		gen t`i' = (year == `i')
			
			
	}
}	
	
	
*Treat * Post
foreach treat in `treatsid' `treatscomm'  {
			gen t_`treat' = (post==1)* `treat'
}

	
/**********************************/
/* Idiosyncratic Shocks           */
/**********************************/

forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatsid' {

	
		*Matrix for outcomes
		matrix B`treat'_`yvar' = J(6,1,.)

		reghdfe `yvar' post if prepost==1, absorb(nipc)
		local basechg = _b[post]
		
	
		*Diff-in-diff regression
		reghdfe `yvar' t???? t_`treat' `c_id' ///
			if prepost==1 , ///
			cluster(nipc) absorb(nipc)
		
		
		*Store estimates
		local b = _b[t_`treat']
		local se = _se[t_`treat']		
		local nobs = e(N)
		local nclust = e(N_clust)
		local tst = `b'/(`se')

	
		matrix B`treat'_`yvar'[1,1]=`b'
		matrix B`treat'_`yvar'[2,1]=`se'
		matrix B`treat'_`yvar'[3,1]=`tst'
		matrix B`treat'_`yvar'[4,1]=`nobs'
		matrix B`treat'_`yvar'[5,1]=`nclust'
		matrix B`treat'_`yvar'[6,1]=`basechg'

	}
	
}	

*Save output matrices as excel sheet

preserve
drop _all

forvalues y = 1/`ny'{
	local yvar : word `y' of `mainout' 
	
	foreach treat in  `treatsid'{

		svmat B`treat'_`yvar'

	}
}


*********************************************************************************************************************
** Idioyncratic shock effects in "Bidshock0610_mn" columns, placebo shock effects in "Bidoth_mn" columns
** Separate files for full sample and never-exiters (for appendix)
***********************************************************************************************************************

export excel "${path}/Aggregate Shock/replication/output/Table5_idiotreat_continuers`contin'.xlsx",  first(var) replace 
restore

	
/**********************************/
/* Common Shocks               */
/**********************************/
forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatscomm' {

		*Matrix for outcomes
		matrix B`treat'_`yvar' = J(5,1,.)
		
		*Diff-in-diff regression, cluster at industry level
		reghdfe `yvar' t???? t_`treat' `c_com' ///
			if prepost==1 , ///
			cluster(ind4_07) absorb(nipc)
		
	
		local b = _b[t_`treat']
		local se = _se[t_`treat']		
		local nobs = e(N)
		local nclust = e(N_clust)
		local tst = `b'/(`se')	
	

		matrix B`treat'_`yvar'[1,1]=`b'
		matrix B`treat'_`yvar'[2,1]=`se'
		matrix B`treat'_`yvar'[3,1]=`tst'
		matrix B`treat'_`yvar'[4,1]=`nobs'
		matrix B`treat'_`yvar'[5,1]=`nclust'
		
	}	
	
}	

*Save output matrices as excel sheet

preserve
drop _all

forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 
	
	foreach treat in  `treatscomm' {
	
		svmat B`treat'_`yvar'
		
	}
}

*********************************************************************************************************************
** Common shock effects in "Bcomshock0610_mn" columns, placebo shock effects in "Bcomoth_mn" columns
** Separate files for full sample and never-exiters (for appendix)
***********************************************************************************************************************

export excel "${path}/Aggregate Shock/replication/output/Table5_commontreat_continuers`contin'.xlsx",  first(var) replace 
restore


}
