
**********************************************
* Tables 6/7: Indiviual Level RF/IV.         *
* Andy Garin (agarin@illinois.edu)           *
***********************************************

cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"

*spec counter
local s = 1

foreach c in  0 1{

global continuers = `c'


clear all
set more off
*read in data

*Read in worker-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/worker_panel.dta", clear

local contin = $continuers


keep if mainsamp==1
gen nace4 = floor(nace5/10)

if $continuers == 1 {
	keep if everexit==0
}

local contin = $continuers

tsset nss year



*Outcomes 		
local outcomes logrealsalary_stayer logrealhwage_stayer logrealsalary logrealhwage  asinhsalary arc_salary /*at firm*/ same_firm /*any job*/ qpemp 
						
local ny : word count `outcomes'



*Treatments


*Shorten name of placebo (rival-firm) shocks
rename l1o4_idshock0610_mn idoth_mn
rename l1o4_comshock0610_mn comoth_mn	



*Main treatments
local treatsid  idshock0610_mn idoth_mn 
local treatscomm  comshock0610_mn comoth_mn

local treatstubs shock0610_mn oth_mn 


***Gen diff in diff samples
gen prepost = inlist(year,2006,2007,2009,2010,2011)
gen post = inlist(year,2009,2010,2011)


**gen treat * post


foreach treat in `treatstubs'{
			gen ti_`treat' = (post==1)* id`treat'
			
			gen tc_`treat' = (post==1)* com`treat'
}
	
	
	
*Make controls interacted with year summies, including annual common
	
forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
		*year dummy
		gen t`i' = (year == `i')

		
		foreach control in expshrAGO expshrESP{
			gen c`i'_`control' = (year == `i') * `control'
		}
		
		*common shock control for idiosyncratic shock specs
		
		gen ctc`i' =  (year == `i') * comshock0610_mn
		

	}
}




/**********************************/
/* Idiosyncratic Shocks           */
/**********************************/


forvalues y = 1/`ny'{

	foreach treat in  `treatstubs' {
	
		cap drop t_i_var
		gen t_i_var = ti_`treat'
		

		local yvar : word `y' of `outcomes' 
		local ytitle : word `y' of `outcomes' 		

		
		local tv = "`treat'"
		local ov = "`yvar'"

		
		matrix IVmat = J(3,7,.)

		*Reduced Form
			
		reghdfe `yvar' t???? t_i_var ctc???? c????_*  ///
			if inrange(year, 2005, 2013) & prepost==1  , ///
			cluster(nipc)  absorb(nss )
			
		local nobs = e(N)

		matrix IVmat[1, 1] = `s', `c', _b[t_i_var], _se[t_i_var], `nobs', 0 , 1	

		
		* IV
	
		ivreghdfe `yvar' t????  c????_* ctc???? (logturnover = t_i_var)    ///
				if inrange(year, 2005, 2013) & prepost==1  , ///
				cluster(nipc)  absorb(nss) ffirst		
		
		matrix F = e(first)	
		local f = F[4,1]
		local nobs = e(N)
		matrix IVmat[2, 1]  = `s', `c', _b[logturnover], _se[logturnover], `nobs', `f' , 2
		
		
		* Naive OLS
	
		reghdfe `yvar' t????  c????_* ctc???? logturnover    ///
				if inrange(year, 2005, 2013) & prepost==1  , ///
				cluster(nipc)  absorb(nss)	
		
		matrix IVmat[3, 1]  = `s', `c', _b[logturnover], _se[logturnover], `nobs', 0 , 3
		
		

		*Write output from specification to disk 
		
		preserve
		
		drop _all

		svmat  IVmat
		
		rename IVmat1 spec
		rename IVmat2 continuers
		rename IVmat3 beta
		rename IVmat4 se
		rename IVmat5 n
		rename IVmat6 f
		rename IVmat7 regtemp
		gen outvar =  "`ov'" 
		gen tvar = "`tv'"    	
		gen common = 0
		
		gen regtype = "RF" if regtemp==1
		replace regtype = "IV" if regtemp==2
		replace regtype = "OLS" if regtemp==3
		
		replace common = . if regtemp ==3
		drop regtemp
		
		
		save "${path}/Aggregate Shock/replication/temp/IV_`s'.dta", replace
		
		
		restore
		
		
		local s = `s' + 1	
		

			
		
	}
}


/**********************************/
/* Common Shocks		           */
/**********************************/

forvalues y = 1/`ny'{

	foreach treat in  `treatstubs' {
	
		cap drop t_c_var
		gen t_c_var = tc_`treat'
		

		local yvar : word `y' of `outcomes' 
		local ytitle : word `y' of `outcomes' 		

		
		local tv = "`treat'"
		local ov = "`yvar'"

		
		*Do not need to do OLS again
		matrix IVmat = J(2,7,.)

		*Reduced Form
			
		reghdfe `yvar' t???? t_c_var  c????_*  ///
			if inrange(year, 2005, 2013) & prepost==1  , ///
			cluster(nace4)  absorb(nss )
			
		local nobs = e(N)

		matrix IVmat[1, 1] = `s', `c', _b[t_c_var], _se[t_c_var], `nobs', 0	, 1

		
		* IV
	
		ivreghdfe `yvar' t????  c????_*  (logturnover = t_c_var)    ///
				if inrange(year, 2005, 2013) & prepost==1  , ///
				cluster(nace4)  absorb(nss) ffirst		
		
		matrix F = e(first)	
		local f = F[4,1]
		local nobs = e(N)
		matrix IVmat[2, 1]  = `s', `c', _b[logturnover], _se[logturnover], `nobs', `f', 2
		
		
		

		*Write output from specification to disk 
		
		preserve
		
		drop _all

		svmat  IVmat
		
		rename IVmat1 spec
		rename IVmat2 continuers
		rename IVmat3 beta
		rename IVmat4 se
		rename IVmat5 n
		rename IVmat6 f
		rename IVmat7 regtemp
		gen outvar =  "`ov'" 
		gen tvar = "`tv'"    	
		gen common = 1
		
		gen regtype = "RF" if regtemp==1
		replace regtype = "IV" if regtemp==2
		drop regtemp
		
		save "${path}/Aggregate Shock/replication/temp/IV_`s'.dta", replace
		
		
		restore
		
		
		local s = `s' + 1	
		

			
		
	}
}

	

}


/******************/
/**Compile output**/
/******************/

local max = `s'-1

use "${path}/Aggregate Shock/replication/temp/IV_1.dta", clear

forvalues i = 2/`max' {
	append using "${path}/Aggregate Shock/replication/temp/IV_`i'.dta"
}


save "${path}/Aggregate Shock/replication/output/Tables_6_7.dta", replace
export excel   "${path}/Aggregate Shock/replication/output/Tables_6_7.xlsx", replace firstrow(variables)



*clear files
forvalues i = 1/`max' {
	erase "${path}/Aggregate Shock/replication/temp/IV_`i'.dta"
}
 
