**********************************************
* Table 8: Robustness					      *
* Andy Garin (agarin@illinois.edu)           *
***********************************************

cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"

foreach c in 0 1{

global continuers = `c'


clear all
set more off
*Read in worker-level cleaned data, use original (not replication) copy
use "${path}/Aggregate Shock/Data/worker_panel.dta", clear


local contin = $continuers

cap log close



if $continuers == 1 {
	keep if everexit==0
}
				
gen ind4_07 = floor(nace5/10)	
gen ind2_07 = floor(nace5/1000)
					
				
local mainout  logrealsalary_stayer  
local ny : word count `mainout'

*Extra controls made by 1_1 code. Read in original copy (not replication copy) here
merge m:1 nipcbdp using  "${path}/Aggregate Shock/Data/extracontrols_for_emp.dta", keep(1 3) nogen
merge m:1 nipcbdp using  "${path}/Aggregate Shock/Data/treatments_for_emp.dta", keep(1 3) nogen keepusing(shock0306hs6)


local treatsid   idshock0610_mn  

gen prepost = inlist(year,2006,2007,2009,2010,2011)
gen post = inlist(year,2009,2010,2011)
/*Define Specs*/

/*controls*/
local c1 = ""
local c2 = "cA????_*"
local c3 = "cB????_*"
local c4 = "cC????_*"
local c5 = "cA????_* cD????_*"
local c6 = "cA????_* cE????_* " 
local c7 = "cA????_* cF????_* " 
local c8 = "cA????_* cG????_* " 
local c9 = "cA????_* " /*trigger 4 prod fe*/
local c10 = "cA????_* " /*trigger expanded sample*/

local f = ""

local s1 = "& mainsamp==1"
local s2 = " " /*Include Large Firms*/

/*Make Event Study RHS Variables*/

gen logbasesal = log(baserealsalary)

forvalues i = 2005/2013 {
	*omit 2007
	if (`i' != 2007) {
	
		*Control x Year
		
		foreach control in comshock0610_mn expshrAGO expshrESP  {
			gen cA`i'_`control' = (year == `i') * `control'
		}
		
		foreach control in expshrAGO expshrESP  {
			gen cB`i'_`control' = (year == `i') * `control'
		}	
		
		foreach control in comshock0610_mn {
			gen cC`i'_`control' = (year == `i') * `control'
		}
		

		foreach control in lexports_pre exports_pre expint_new_pre   {
			gen cD`i'_`control' = (year == `i') * `control'
		}		
		foreach control in  lturnover_pre lemployees_pre employees_pre turnover_pre lognomhwage_pre lva_alt1_l_pre ltotal_assets_pre ftcshr_pre hirertpre{
			gen cE`i'_`control' = (year == `i') * `control'
		}		

		foreach control in  lndest_pre shock0306hs6 lHHI_pre expshrAGO expshrESP expshrUSA expshrNLD expshrMOZ expshrGBR expshrFRA expshrDEU expshrCPV expshrBRA expshrBEL{
			gen cF`i'_`control' = (year == `i') * `control'
		}	
		foreach control in  tenure_pre age_pre logbasesal female coldeg nohs {
			gen cG`i'_`control' = (year == `i') * `control'
		}	
		
		*year dummy
		gen t`i' = (year == `i')
			
			
	}
}	
	
foreach treat in `treatsid' `treatscomm'  {
			gen t_`treat' = (post==1)* `treat'
}

	
/**********************************/
/* Idiosyncratic Shocks           */
/**********************************/
forvalues y = 1/`ny'{

	local yvar : word `y' of `mainout' 

	foreach treat in  `treatsid' {

		matrix B_`treat' = J(9,2,.)
		matrix IV_`treat' = J(9,2,.)
		
		
		reghdfe `yvar' post if prepost==1  `s`smp'' , absorb(nss)
		local basechg = _b[post]
		
		
		foreach cs in 1 2 3 4 5 6 7 8 9 10{
				
			
			if `cs'==9 {
				local f = "mainhs4#year"
			}


			if `cs'!=9{
				local f = ""
			}
			
			
			if `cs'==10 {
				local smp = 2
			}


			if `cs'!=10{
				local smp = 1
			}
									
			
			
			**REDUCED FORM
			
			*Matrix for outcomes
			matrix temp = J(9,1,.)

		
			reghdfe `yvar' t???? t_`treat' `c`cs''   ///
				if prepost==1 `s`smp'' , ///
				cluster(nipc) absorb(nss `f')
			
			local b = _b[t_`treat']
			local se = _se[t_`treat']		
			local nobs = e(N)
			local nclust = e(N_clust)
			local tst = `b'/(`se')
			
			local n_indiv = e(dof_table)[1,1]
		
			matrix temp[1,1]=`b'
			matrix temp[2,1]=`se'
			matrix temp[3,1]=`tst'
			matrix temp[4,1]=`nobs'
			matrix temp[5,1]=`nclust'
			matrix temp[6,1]=`smp'	
			matrix temp[7,1]=`cs'	
			matrix temp[8,1]=`n_indiv'
			matrix temp[9,1]=`basechg'
			matrix B_`treat' = [B_`treat', temp]
			
			
			
			***IV
			
			matrix temp = J(9,1,.)

			ivreghdfe `yvar' t????  `c`cs'' (logturnover = t_`treat')   ///
				if prepost==1 `s`smp'' , ///
				cluster(nipc) absorb(nss `f')

			matrix esttemp = _b[logturnover], _se[logturnover]		
			local nobs = e(N)
			local nclust = e(N_clust)
			local tst = esttemp[1,1]/esttemp[1,2]
	
			local n_indiv = e(K1)	

			matrix temp[1,1]=esttemp[1,1]
			matrix temp[2,1]=esttemp[1,2]
			matrix temp[3,1]=`tst'
			matrix temp[4,1]=`nobs'
			matrix temp[5,1]=`nclust'
			matrix temp[6,1]=`smp'	
			matrix temp[7,1]=`cs'	
			matrix temp[8,1]=`n_indiv'
			matrix temp[9,1]=`basechg'
			matrix IV_`treat' = [IV_`treat', temp]
					
			
		}
		
		
	
	*Save matrices
	
	}

	preserve
	drop _all
	
	
	foreach treat in  `treatsid'{
		svmat B_`treat'
		svmat IV_`treat'
	}
	
	export excel "${path}/Aggregate Shock/replication/output/Table_8_contin`contin'.xlsx",  first(var) replace 
	restore
	
}	


}


