
*Control = 1: Add group specific annual effects

*************************************
***Check Heterogeneity Drivers*****
***********************************


cap mkdir "${path}/Aggregate Shock/replication"
cap mkdir "${path}/Aggregate Shock/replication/data_out"
cap mkdir "${path}/Aggregate Shock/replication/temp"
cap mkdir "${path}/Aggregate Shock/replication/output"


***************************************************
*Start by reading in firm sample and cross-tabbing
***************************************************

clear all
set more off

set matsize 11000

use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear


*Base year industry comparisons

keep if year == 2007
keep if mainsamp==1


*Hi versus low	
tabstat ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l, by(hi_ind5d_ooswmn_quit_perm) statistics(mean sem)

*Correlations
foreach var in ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l{
	local intnum  = `intnum' + 1
	reg ind5d_ooswmn_quit_perm `var' , cluster(nace5)
	reg hi_ind5d_ooswmn_quit_perm `var' , cluster(nace5)
}

reg hi_ind5d_ooswmn_quit_perm ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l

*get hi quit rate residualized on other stuff
reg ind5d_ooswmn_quit_perm ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l
predict hetvar_resid, residuals


summ hetvar_resid if year==2007, d
local med = r(p50)
gen hi_resid=0 if hetvar_resid < `med'
replace hi_resid=1 if hetvar_resid >`med' & hetvar_resid!=.
	


keep nipc hi_resid
tempfile hi_resid 
save `hi_resid'



clear


***************************************************
*Heterogeneity, With Controls for INTS
***************************************************

local s = 1

foreach c in  0 1{
foreach ct in 0 1{

global control = `ct'
global continuers = `c'


foreach hetvar in  resid cushion ind5d_ooswmn_perm_medtenure ind5d_ooswmn_quit_perm HHIemp akmperm {


use "${path}/Aggregate Shock/Data/worker_panel.dta", clear


local firststage logturnover 

local nx : word count `firststage'				
local outcomes  logrealhwage_stayer logrealsalary_stayer asinhsalary arc_salary
						
local ny : word count `outcomes'


local treats  idshock0610_mn 



local contin = $continuers
local contr = $control


keep if mainsamp==1

if $continuers == 1 {
	keep if everexit==0
}


*merge on other het things
merge m:1 nipc using `hi_resid', keep(3) nogen
merge m:1 nss nipcbdp using "${path}/Aggregate Shock/Data/worker_cushions.dta", keep(1 3) nogen

summ wagecushion2007 if year == 2007, d
local med = r(p50)

gen hi_cushion = wagecushion2007 > `med' if wagecushion2007!=.





***Gen diff in diff samples
gen prepost1 = inlist(year,2006,2007,2009,2010,2011)
gen post1 = inlist(year,2009,2010,2011)




gen hihet=hi_`hetvar' 




**gen treat * post`w' variablesm
**note: post`w' absorved by year FE, treat absorbed by person

forvalues i = 1/1 {
	foreach treat in `treats'{
			gen t`i'_`treat' = (post`i'==1)* `treat'
			
			
			
			gen tl`i'_`treat' = (post`i'==1) * `treat'*(hihet==0)
			gen th`i'_`treat' = (post`i'==1) *  `treat'*(hihet==1)		
			

	}
	

		gen c0inter`i' = (post`i'==1)  *hihet
		
}


gen a = 0
	
forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
		*year dummy
		gen t`i' = (year == `i')


		*IN THIS VERSION, C0 and C1 changes yearly vs post interaction, but not control list
		foreach control in comshock0610_mn expshrAGO expshrESP{
			gen c0`i'_`control' = (year == `i') * `control'	
			gen c1`i'_`control' = (year == `i') * `control'
		}
		
		gen c1inter`i' = (year == `i') *hihet		
	
	}
}





/*Y vars: Second stage and RFs */
/*For each shock, want All 3 periods, RF and IV, IV with all 3 Z vars*/

foreach treat in  `treats' {
	local r replace
	cap log close
	local k = 0
	forvalues y = 1/`ny'{
	
		local k = `k' +1
		foreach w in 1  {

		cap drop tvar
		gen tvar = t1_`treat'
		
		cap drop htvar
		cap drop ltvar
		gen htvar = th1_`treat'
		gen ltvar = tl1_`treat'
		
		local xsd = 0
		local xmn = 0	
		
		local yvar : word `y' of `outcomes' 
		local ytitle : word `y' of `outcomes' /* `outcomes_titles' */
		
		local tv = "`treat'"
		local ov = "`yvar'"
		local hv = "`hetvar'"

		*In this version, fix 1 treatment, accumulate 5 rows for the RF and IV specs
		matrix IVmat = J(3,11,.)

		
		*Main Effect

			
			reghdfe `yvar' t???? tvar   c`ct'????_*  ///
				if inrange(year, 2005, 2013) & prepost`w'==1  , ///
				cluster(nipc)  absorb(nss )
			local nobs = e(N)	
				
			matrix IVmat[1, 1] = `s', `c', `ct', _b[tvar], _se[tvar], 0 ,0,  `nobs', 0, 0 , 1	

				

	*****Heterogeneity: Do IV FS and RF Only
		

			*For each period, do reduced form and loop over IV vars
		
			*Reduced Form
			
			
			reghdfe `yvar' t???? htvar ltvar  c`ct'inter*  c`ct'????_*     ///
				if inrange(year, 2005, 2013) & prepost`w'==1  , ///
				cluster(nipc)  absorb(nss )
			
			local nobs = e(N)			
			test htvar = ltvar
			local eqp = r(p)
					
			matrix IVmat[2, 1] = `s', `c', `ct', _b[htvar], _se[htvar], _b[ltvar], _se[ltvar],  `nobs', `eqp', 0 , 2
			
	
			*IV
			
			forval xx = 1/`nx'{
				local xvar : word `xx' of `firststage' 
				cap drop xvar_lo
				cap drop xvar_hi
				cap drop xvar
				gen xvar = `xvar'
				gen xvar_lo = `xvar' *(hihet==0)
				gen xvar_hi = `xvar' *(hihet==1)
			
				ivreghdfe `yvar' t????  c`ct'inter*   c`ct'????_*  ( xvar_lo  xvar_hi = htvar ltvar)     ///
					if inrange(year, 2005, 2013) & prepost`w'==1   , ///
					cluster(nipc)  absorb(nss) ffirst
					
				local nobs = e(N)	
				matrix F = e(first)	
				local fsf = F[4,1]
				test xvar_lo  = xvar_hi
				local eqp = r(p)
				
				matrix IVmat[3, 1] = `s', `c', `ct', _b[xvar_hi], _se[xvar_hi], _b[xvar_lo], _se[xvar_lo],  `nobs', `eqp', `fsf' , 3
				
					
				
				drop xvar_lo 
				drop xvar_hi
				drop xvar

			}
			
			preserve
		
			drop _all

			svmat  IVmat
			
			rename IVmat1 specid
			rename IVmat2 continuers
			rename IVmat3 nocontrols
			rename IVmat4 beta_hi
			rename IVmat5 se_hi
			rename IVmat6 beta_lo
			rename IVmat7 se_lo
			rename IVmat8 n
			rename IVmat9 eqp
			rename IVmat10 f
			rename IVmat11 spectype
			gen outvar =  "`ov'" 
			gen tvar = "`tv'"    	
			gen hvar = "`hv'"   
			
			save "${path}/Aggregate Shock/replication/temp/IVfh_`s'.dta", replace
			restore
		
		
			local s = `s' + 1	
			
		}
		
		
		

			
		
	}
	
}

}

	
}
}



/************************************************************/
/**** Common Shocks***************************************/
/*********************************************************/


***************************************************
*Start by reading in firm sample and cross-tabbing
***************************************************

clear all
set more off

set matsize 11000

use "${path}/Aggregate Shock/Data/analysis_samp.dta", clear


*Base year industry comparisons

keep if year == 2007
keep if mainsamp==1


*Hi versus low	
tabstat ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l, by(hi_ind5d_ooswmn_quit_perm) statistics(mean sem)

*Correlations
foreach var in ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l{
	local intnum  = `intnum' + 1
	reg ind5d_ooswmn_quit_perm `var' , cluster(nace5)
	reg hi_ind5d_ooswmn_quit_perm `var' , cluster(nace5)
}

reg hi_ind5d_ooswmn_quit_perm ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l

*get hi quit rate residualized on other stuff
reg ind5d_ooswmn_quit_perm ind5d_grow5yr HHIemp logrealhwage logrealsalary logemp lturnover_l
predict hetvar_resid, residuals


summ hetvar_resid if year==2007, d
local med = r(p50)
gen hi_resid=0 if hetvar_resid < `med'
replace hi_resid=1 if hetvar_resid >`med' & hetvar_resid!=.
	


keep nipc hi_resid
tempfile hi_resid 
save `hi_resid'



clear


***************************************************
*Heterogeneity, With Controls for INTS
***************************************************

foreach c in  0 1{
foreach ct in 0 1{

global control = `ct'
global continuers = `c'


foreach hetvar in  resid cushion ind5d_ooswmn_perm_medtenure ind5d_ooswmn_quit_perm HHIemp akmperm {


use "${path}/Aggregate Shock/Data/worker_panel.dta", clear


local firststage logturnover 

local nx : word count `firststage'				
local outcomes  logrealhwage_stayer logrealsalary_stayer  asinhsalary arc_salary 
						
local ny : word count `outcomes'


local treats  comshock0610_mn 

gen ind4_07 = floor(nace5/10)	

local contin = $continuers
local contr = $control


keep if mainsamp==1

if $continuers == 1 {
	keep if everexit==0
}


*merge on other het things
merge m:1 nipc using `hi_resid', keep(3) nogen
merge m:1 nss nipcbdp using "${path}/Aggregate Shock/Data/worker_cushions.dta", keep(1 3) nogen

summ wagecushion2007 if year == 2007, d
local med = r(p50)

gen hi_cushion = wagecushion2007 > `med' if wagecushion2007!=.





***Gen diff in diff samples
gen prepost1 = inlist(year,2006,2007,2009,2010,2011)
gen post1 = inlist(year,2009,2010,2011)




gen hihet=hi_`hetvar' 




**gen treat * post`w' variablesm
**note: post`w' absorved by year FE, treat absorbed by person

forvalues i = 1/1 {
	foreach treat in `treats'{
			gen t`i'_`treat' = (post`i'==1)* `treat'
			
			
			
			gen tl`i'_`treat' = (post`i'==1) * `treat'*(hihet==0)
			gen th`i'_`treat' = (post`i'==1) *  `treat'*(hihet==1)		
			

	}
	

		gen c0inter`i' = (post`i'==1)  *hihet
		
}


gen a = 0
	
forvalues i = 2005/2013 {

	*omit 2007
	if (`i' != 2007) {
	
		*year dummy
		gen t`i' = (year == `i')

		
		foreach control in  expshrAGO expshrESP{
			gen c0`i'_`control' = (year == `i') * `control'	
			gen c1`i'_`control' = (year == `i') * `control'
		}
		
		gen c1inter`i' = (year == `i') *hihet		
	
	}
}





/*Y vars: Second stage and RFs */
/*For each shock, want All 3 periods, RF and IV, IV with all 3 Z vars*/

foreach treat in  `treats' {
	local r replace
	cap log close
	local k = 0
	forvalues y = 1/`ny'{
	
		local k = `k' +1
		foreach w in 1  {

		cap drop tvar
		gen tvar = t1_`treat'
		
		cap drop htvar
		cap drop ltvar
		gen htvar = th1_`treat'
		gen ltvar = tl1_`treat'
		
		local xsd = 0
		local xmn = 0	
		
		local yvar : word `y' of `outcomes' 
		local ytitle : word `y' of `outcomes' /* `outcomes_titles' */
		
		local tv = "`treat'"
		local ov = "`yvar'"
		local hv = "`hetvar'"

		*In this version, fix 1 treatment, accumulate 5 rows for the RF and IV specs
		matrix IVmat = J(3,11,.)

		
		*Main Effect

			
			reghdfe `yvar' t???? tvar   c`ct'????_*  ///
				if inrange(year, 2005, 2013) & prepost`w'==1  , ///
				cluster(ind4_07)  absorb(nss )
			local nobs = e(N)	
				
			matrix IVmat[1, 1] = `s', `c', `ct', _b[tvar], _se[tvar], 0 ,0,  `nobs', 0, 0 , 1	

				

	*****Heterogeneity: Do IV FS and RF Only
		

			*For each period, do reduced form and loop over IV vars
		
			*Reduced Form
			
			
			reghdfe `yvar' t???? htvar ltvar  c`ct'inter*  c`ct'????_*     ///
				if inrange(year, 2005, 2013) & prepost`w'==1  , ///
				cluster(ind4_07)  absorb(nss )
			
			local nobs = e(N)			
			test htvar = ltvar
			local eqp = r(p)
					
			matrix IVmat[2, 1] = `s', `c', `ct', _b[htvar], _se[htvar], _b[ltvar], _se[ltvar],  `nobs', `eqp', 0 , 2
			
	
			*IV
			
			forval xx = 1/`nx'{
				local xvar : word `xx' of `firststage' 
				cap drop xvar_lo
				cap drop xvar_hi
				cap drop xvar
				gen xvar = `xvar'
				gen xvar_lo = `xvar' *(hihet==0)
				gen xvar_hi = `xvar' *(hihet==1)
			
				ivreghdfe `yvar' t????  c`ct'inter*   c`ct'????_*  ( xvar_lo  xvar_hi = htvar ltvar)     ///
					if inrange(year, 2005, 2013) & prepost`w'==1   , ///
					cluster(ind4_07)  absorb(nss) ffirst
					
				local nobs = e(N)	
				matrix F = e(first)	
				local fsf = F[4,1]
				test xvar_lo  = xvar_hi
				local eqp = r(p)
				
				matrix IVmat[3, 1] = `s', `c', `ct', _b[xvar_hi], _se[xvar_hi], _b[xvar_lo], _se[xvar_lo],  `nobs', `eqp', `fsf' , 3
				
					
				
				drop xvar_lo 
				drop xvar_hi
				drop xvar

			}
			
			preserve
		
			drop _all

			svmat  IVmat
			
			rename IVmat1 specid
			rename IVmat2 continuers
			rename IVmat3 nocontrols
			rename IVmat4 beta_hi
			rename IVmat5 se_hi
			rename IVmat6 beta_lo
			rename IVmat7 se_lo
			rename IVmat8 n
			rename IVmat9 eqp
			rename IVmat10 f
			rename IVmat11 spectype
			gen outvar =  "`ov'" 
			gen tvar = "`tv'"    	
			gen hvar = "`hv'"   
			
			save "${path}/Aggregate Shock/replication/temp/IVfh_`s'.dta", replace
			restore
		
		
			local s = `s' + 1	
			
		}
		
		
		

			
		
	}
	
}

}

	
}
}






/**Compile output**/

local max = `s'-1

use "${path}/Aggregate Shock/replication/temp/IVfh_1.dta", clear

forvalues i = 2/`max' {
	append using "${path}/Aggregate Shock/replication/temp/IVfh_`i'.dta"
}


save "${path}/Aggregate Shock/replication/output/Table_9_alt.dta", replace
export excel  "${path}/Aggregate Shock/replication/output/Table_9_alt.xlsx", replace firstrow(variables)

*clear files
forvalues i = 1/`max' {
	erase "${path}/Aggregate Shock/replication/temp/IVfh_`i'.dta"
}
 

